#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Function:Install license
Date:2018.12.13
"""
import sys
import time


Export_To_HELP = '''
The license file URI to be export to.
Export to file path could be the BMC local path URI (under /tmp directory), 
or remote path URI (protocols HTTPS, SFTP, NFS, CIFS, and SCP are supported).
'''


def exportlicense_init(parser, parser_list):
    """
    :Function:Install license subcommand
    :param parser:major command argparser
    :param parser_list:save subcommand parser list
    :return:
    """
    sub_parser = parser.add_parser('exportlicense',
                                   help='''export license''')
    sub_parser.add_argument('-T', dest='exportTo',
                            type=str,
                            required=True,
                            help=Export_To_HELP)
    parser_list['exportlicense'] = sub_parser
    return 'exportlicense'


def exportlicense(client, parser, args):
    """
    :Function:Install license
    :param client:RedfishClient object
    :param parser:subcommand argparser. Export error messages when parameters are incorrect.
    :param args:parameter list
    :return:
    """
    # Parameter verification
    if parser is None or args is None:
        return None

    # Obtain the slot number.
    slotid = client.get_slotid()
    if slotid is None:
        return None

    url = "/redfish/v1/Managers/%s/LicenseService" \
          "/Actions/LicenseService.ExportLicense" % slotid
    # Construct payload.
    payload = {
        "Type": "URI",
        "Content": args.exportTo
    }
    resp = client.create_resource(url, payload)

    if resp is None:
        return None

    if resp.get('status_code') == 202:
        time.sleep(1)
        resp_task = client.print_task_prog(resp)
        if resp_task is None:
            return None

        if resp_task == 'Exception':
            _resptaskparse(resp, client)
            sys.exit(144)
    else:
        _respparse(resp)

    return resp


def _resptaskparse(resp, client):
    """
    :Function:Handle exception task state
    :param client:RedfishClient object
    :param resp:response information
    :return:
    """

    taskid = resp['resource']['@odata.id']

    sys_resp = client.get_resource(taskid)
    if sys_resp is None:
        sys.exit(127)

    if sys_resp['status_code'] != 200:
        info = sys_resp['message']['error']['@Message.ExtendedInfo'][0]
        message = (info['Message']).lower()
        print 'Failure: ' + message[:-1]
    else:
        # Return the task failure details
        message = (sys_resp['resource']['Messages']['Message']).lower()
        print 'Failure: ' + message[:-1]


def _respparse(resp):
    """
    :Function:Handle resp which is not 202
    :param resp:response information
    :return:
    """
    if resp['status_code'] == 200:
        print 'Success: successfully completed request'
        return None
    else:
        info = resp['message']['error']['@Message.ExtendedInfo'][0]
        message_id = info.get('MessageId')
        if 'Format' in message_id:
            print 'Failure: import failed due to invalid path'
        else:
            message = (info.get('Message')).lower()
            print 'Failure: ' + message[:-1]
